from .atf_file_attachment import AtfFileAttachment
from .atf_file_info import AtfFileInfo
from .atf_file_type import AtfFileType
from .hlt_blank_template import HltBlankTemplate
from .hlt_call_doctor import HltCallDoctor
from .hlt_call_doctor_status import HltCallDoctorStatus
from .hlt_doc_prvd import HltDocPrvd
from .hlt_doctor_time_table import HltDoctorTimeTable
from .hlt_doctor_visit_table import HltDoctorVisitTable
from .hlt_lpu_doctor import HltLpuDoctor
from .hlt_med_record import HltMedRecord
from .hlt_mkab import HltMkab, Gender
from .hlt_reason_care import HltReasonCare
from .hlt_representative_mkab import HltRepresentativeMkab
from .hlt_smtap import HltSmTap
from .hlt_tap import HltTap
from .hlt_type_call_doctor import HltTypeCallDoctor
from .hlt_uchastok import HltUchastok
from .hlt_visit_history import HltVisitHistory
from .kla_address import KlaAddress
from .kla_house import KlaHouse
from .kla_kladr import KlaKladr
from .kla_street import KlaStreet
from .oms_department import OmsDepartment
from .oms_kl_age_group import OmsKlAgeGroup
from .oms_kl_dd_service import OmsKlDDService
from .oms_kl_department_profile import OmsKlDepartmentProfile
from .oms_kl_department_type import OmsKlDepartmentType
from .oms_kl_disease_type import OmsKlDiseaseType
from .oms_kl_health_group import OmsKlHealthGroup
from .oms_kl_med_care_type import OmsKlMedCareType
from .oms_kl_profit_type import OmsKlProfitType
from .oms_kl_reason_type import OmsKlReasonType
from .oms_kl_soc_status import OmsKlSocStatus
from .oms_kl_stat_cure_result import OmsKlStatCureResult
from .oms_kl_tip_oms import OmsKlTipOms
from .oms_kl_visit_place import OmsKlVisitPlace
from .oms_kl_visit_result import OmsKlVisitResult
from .oms_lpu import OmsLpu
from .oms_mkb import OmsMkb
from .oms_okato import OmsOkato
from .oms_okved import OmsOkved
from .oms_organisation import OmsOrganisation
from .oms_prvd import OmsPrvd
from .oms_prvs import OmsPrvs
from .oms_service_medical import OmsServiceMedical
from .oms_smo import OmsSmo
from .oms_type_doc import OmsTypedoc
from .x_user import XUser
